# GeostellarClient

This is a Ruby wrapper for the [Geostellar API](http://geostellar.com/developers/join).  You will need an API key to use this gem.

## Installation

Add this line to your application's Gemfile:

```ruby
gem 'geostellar_client'
```

And then execute:

    $ bundle

Or install it yourself as:

    $ gem install geostellar_client


## Usage

Configure the client with your API key:

```ruby
GeostellarClient.api_key = YOURAPIKEY
```

### User

A user has the following attributes:

```
id, Integer
email, String
phone, String
first_name, String
last_name, String
street_address_1, String
street_address_2, String
city, String
state, String
zip_code, String
password, String
```

`password` is only used internally when talking to the user creation API.  The User object returned by `User#create` has a password value of `nil`.

#### To fetch a user:

```ruby
user = GeostellarClient::User.find(1)
```

#### To create a user:

```ruby
attributes = {
  email: 'someemail@example.com',
  password: 'password',
  phone: '123456789',
  first_name: 'Foo',
  last_name: 'Bar',
  street_address_1: '1 Street',
  street_address_2: 'Address',
  city: 'The City',
  state: 'OR',
  zip_code: '12345',
}

user = GeostellarClient::User.create(attributes)
```

When successful this returns a `User` object.  Otherwise a `GeostellarClient::UserCreationError` is raised, with the message returned by the API.


## Development

After checking out the repo, run `bin/setup` to install dependencies.  Rename `spec/credentials.yml.sample` to `spec/credentials.yml` and replace the dummy API key with your own.

Then, run `rake rspec` to run the tests. You can also run `bin/console` for an interactive prompt that will allow you to experiment.

To install this gem onto your local machine, run `bundle exec rake install`. To release a new version, update the version number in `version.rb`, and then run `bundle exec rake release`, which will create a git tag for the version, push git commits and tags, and push the `.gem` file to [rubygems.org](https://rubygems.org).

### To-do

- Update user
- Log-in
- Log-out
- PV Module, Incentive, Solar estimate models and API calls
- Address and monthly bill search


## Contributing

Bug reports and pull requests are welcome on GitHub at https://github.com/jpmoral/geostellar_client. This project is intended to be a safe, welcoming space for collaboration, and contributors are expected to adhere to the [Contributor Covenant](contributor-covenant.org) code of conduct.


## License

The gem is available as open source under the terms of the [MIT License](http://opensource.org/licenses/MIT).

